package cc.fascinated.backend.controller;

import cc.fascinated.backend.exception.impl.ResourceNotFoundException;
import cc.fascinated.backend.model.Paste;
import cc.fascinated.backend.service.PasteService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.MimeTypeUtils;
import org.springframework.web.bind.annotation.*;

import java.awt.datatransfer.MimeTypeParseException;
import java.util.Map;

/**
 * @author Fascinated (fascinated7)
 */
@Controller
@RequestMapping(value = "/")
public class IndexController {

    private final PasteService pasteService;

    @Autowired
    public IndexController(PasteService pasteService) {
        this.pasteService = pasteService;
    }

    @GetMapping(value = "/")
    public String home() {
        return "index";
    }

    /**
     * This is to allow for Hastebin compatibility.
     */
    @PostMapping(value = "/documents")
    public ResponseEntity<?> uploadPaste(@RequestBody String content, @RequestHeader(value = HttpHeaders.CONTENT_TYPE, required = false) String contentType) {
        String id = pasteService.createPaste(content, contentType);
        return ResponseEntity.ok(Map.of("key", id));
    }


    @GetMapping(value = "/{id}", produces = MimeTypeUtils.TEXT_HTML_VALUE)
    public String paste(@PathVariable String id, Model model) {
        try {
            Paste paste = pasteService.getPaste(id);
            model.addAttribute("paste", paste);
            model.addAttribute("title", "Paste - " + paste.getId());
            model.addAttribute("rawUrl", "/raw/" + paste.getId());
            return "paste";
        } catch (ResourceNotFoundException ex) {
            return "redirect:/";
        }
    }

    @GetMapping(value = "/raw/{id}", produces = MimeTypeUtils.TEXT_HTML_VALUE)
    public String pasteRaw(@PathVariable String id, Model model) {
        try {
            Paste paste = pasteService.getPaste(id);
            model.addAttribute("paste", paste);
            model.addAttribute("title", "Paste - " + paste.getId() + " (Raw)");
            return "paste-raw";
        } catch (ResourceNotFoundException ex) {
            return "redirect:/";
        }
    }
}
